.. _image_management:

################
Image Management
################

**********************************
Working with a directory of images
**********************************

.. automodapi:: msumastro.image_collection
    :no-inheritance-diagram:
    :skip: Table

***************************************
Turning an image collection into a tree
***************************************

.. module:: msumastro.table_tree

.. autoclass:: TableTree
    :members:
    :undoc-members:

*****************************************
Image class that includes WCS information
*****************************************

.. module:: msumastro.image

.. autoclass:: ImageWithWCS
    :members:
    :undoc-members:
